==> blender_2.42a.orig.tar.gz: blender-2.42a/source/gameengine/Ketsji/KX_IPhysicsController.cpp <==
/**
 * @file KX_IPhysicsController.cpp
 * $Id: KX_IPhysicsController.cpp,v 1.6 2005/03/25 10:33:37 kester Exp $
 *
 * ***** BEGIN GPL/BL DUAL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version. The Blender
 * Foundation also sells licenses for use in proprietary software under
 * the Blender License.  See http://www.blender.org/BL/ for information
 * about this.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
 * All rights reserved.
 *
 * The Original Code is: all of this file.
 *
 * Contributor(s): none yet.
 *
 * ***** END GPL/BL DUAL LICENSE BLOCK *****
 */
#include "KX_IPhysicsController.h"

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "PHY_DynamicTypes.h"

KX_IPhysicsController::KX_IPhysicsController(bool dyna,void* userdata)

:	m_bDyna(dyna),
	m_suspendDynamics(false),
	m_userdata(userdata)
{
}

KX_IPhysicsController::~KX_IPhysicsController()
{
}

==> blender_2.59.orig.tar.gz: blender-2.59/source/gameengine/Ketsji/KX_IPhysicsController.cpp <==
/*
 * @file KX_IPhysicsController.cpp
 * $Id: KX_IPhysicsController.cpp 35171 2011-02-25 13:35:59Z jesterking $
 *
 * ***** BEGIN GPL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
 * All rights reserved.
 *
 * The Original Code is: all of this file.
 *
 * Contributor(s): none yet.
 *
 * ***** END GPL LICENSE BLOCK *****
 */

/** \file gameengine/Ketsji/KX_IPhysicsController.cpp
 *  \ingroup ketsji
 */

#include "KX_IPhysicsController.h"

#include "PHY_DynamicTypes.h"

KX_IPhysicsController::KX_IPhysicsController(bool dyna, bool sensor, bool compound, void* userdata)

:	m_bDyna(dyna),
	m_bSensor(sensor),
	m_bCompound(compound),
	m_suspendDynamics(false),
	m_userdata(userdata)
{
}

KX_IPhysicsController::~KX_IPhysicsController()
{
}
